<?php
/**
 * @file
 * Administration pages for the Yandex.Share module.
 */

/**
 * Returns settings form.
 */
function yashare_admin_settings() {
  $form['settings'] = array(
    '#type' => 'vertical_tabs',
  );
  $form['settings']['general'] = array(
    '#type' => 'fieldset',
    '#title' => t('General settings'),
  );
  $form['settings']['general']['yashare_l10n'] = array(
    '#type' => 'select',
    '#title' => t('Language'),
    '#options' => yashare_get_languages(),
    '#default_value' => yashare_get_language(),
  );
  $form['settings']['general']['yashare_theme'] = array(
    '#type' => 'select',
    '#title' => t('Theme'),
    '#options' => array(
      'default' => t('Default'),
      'dark' => t('Dark'),
      'counter' => t('Counters'),
    ),
    '#default_value' => variable_get('yashare_theme', 'default'),
  );

  $title = variable_get('site_name', 'Drupal');
  if (variable_get('yashare_theme', 'default') == 'counter') {
    $options = array(
      'button' => yashare_render('init-button', '<front>', $title, NULL, 'button'),
      'small' => yashare_render('init-small', '<front>', $title, NULL, 'small'),
    );
  }
  else {
    $options = array(
      'button' => yashare_render('init-button', '<front>', $title, NULL, 'button'),
      'link' => yashare_render('init-link', '<front>', $title, NULL, 'link'),
      'icon' => yashare_render('init-icon', '<front>', $title, NULL, 'icon'),
      'none' => yashare_render('init-none', '<front>', $title, NULL, 'none'),
    );
  }
  $form['settings']['general']['yashare_type'] = array(
    '#type' => 'radios',
    '#title' => t('Type'),
    '#options' => $options,
    '#default_value' => variable_get('yashare_type', 'button'),
  );
  // Dark background for 'dark' theme.
  if (variable_get('yashare_theme', 'default') == 'dark') {
    $form['settings']['general']['yashare_type']['#prefix'] = '<div style="background-color: gray;">';
    $form['settings']['general']['yashare_type']['#suffix'] = '</div>';
  }

  $form['settings']['general']['yashare_block_title'] = array(
    '#type' => 'textfield',
    '#title' => t('Block title'),
    '#default_value' => variable_get('yashare_block_title', ''),
  );
  $form['settings']['general']['yashare_border'] = array(
    '#type' => 'checkbox',
    '#title' => t('Block border'),
    '#default_value' => variable_get('yashare_border', FALSE),
  );
  $form['settings']['general']['yashare_linkunderline'] = array(
    '#type' => 'checkbox',
    '#title' => t('Underline block link'),
    '#default_value' => variable_get('yashare_linkunderline', FALSE),
  );
  $form['settings']['general']['yashare_linkicon'] = array(
    '#type' => 'checkbox',
    '#title' => t('Add icon to the block'),
    '#default_value' => variable_get('yashare_linkicon', FALSE),
  );
  $form['settings']['general']['yashare_image'] = array(
    '#type' => 'checkbox',
    '#title' => t('Pass site logo as image to share'),
    '#default_value' => variable_get('yashare_image', FALSE),
  );

  $services = yashare_services_list();
  // Block settings.
  $form['settings']['block_settings'] = array(
    '#type' => 'fieldset',
    '#title' => t('Block services'),
    '#description' => t('Choose the services to show in block.'),
  );

  $header = array(
    'name' => t('Name'),
    'dark' => t('Dark theme'),
    'counter' => t('Counters theme'),
  );
  $options = array();
  $weight = -30;
  $enabled_services = yashare_get_enabled_services('block');
  $form['settings']['block_settings']['yashare_block_services'] = array();
  foreach (array_keys($enabled_services + $services) as $codename) {
    $options[$codename] = array(
      'name' => $services[$codename]['name'],
      'dark' => $services[$codename]['dark'] ? t('Yes') : t('No'),
      'counter' => $services[$codename]['counter'] ? t('Yes') : t('No'),
      '#attributes' => array('class' => array('draggable')),
    );
    $form['settings']['block_settings']['yashare_block_services'][$codename . '_block_weight'] = array(
      '#tree' => FALSE,
      '#type' => 'weight',
      '#delta' => 30,
      '#default_value' => $weight++,
      '#attributes' => array('class' => array('yashare-block-services-weight')),
    );
  }
  $form['settings']['block_settings']['yashare_block_services'] += array(
    '#type' => 'tableselect',
    '#title' => t('Block services'),
    '#header' => $header,
    '#options' => $options,
    '#default_value' => $enabled_services,
    '#pre_render' => array('yashare_block_services_pre_render'),
  );

  // Popup settings.
  $form['settings']['popup_settings'] = array(
    '#type' => 'fieldset',
    '#title' => t('Popup settings'),
    '#description' => t('Popup settings are ignored if you are using Counters theme.'),
  );
  $form['settings']['popup_settings']['yashare_popup_title'] = array(
    '#type' => 'textfield',
    '#title' => t('Popup title'),
    '#default_value' => variable_get('yashare_popup_title', ''),
  );
  $form['settings']['popup_settings']['yashare_popup_link'] = array(
    '#type' => 'checkbox',
    '#title' => t('Show link for copy'),
    '#default_value' => variable_get('yashare_popup_link', FALSE),
  );
  $form['settings']['popup_settings']['yashare_popup_codeforblog'] = array(
    '#type' => 'checkbox',
    '#title' => t('Show code for blog'),
    '#default_value' => variable_get('yashare_popup_codeforblog', FALSE),
  );
  $form['settings']['popup_settings']['yashare_popup_vdirection'] = array(
    '#type' => 'select',
    '#title' => t('Popup direction'),
    '#options' => array(
      0 => t('Auto'),
      'up' => t('Up'),
      'down' => t('Down'),
    ),
    '#default_value' => variable_get('yashare_popup_vdirection', 0),
  );

  $header = array(
    'name' => t('Name'),
    'dark' => t('Dark theme'),
  );
  $options = array();
  $weight = -30;
  $enabled_services = yashare_get_enabled_services('popup');
  $form['settings']['popup_settings']['yashare_popup_services'] = array();
  foreach (array_keys($enabled_services + $services) as $codename) {
    $options[$codename] = array(
      'name' => $services[$codename]['name'],
      'dark' => $services[$codename]['dark'] ? t('Yes') : t('No'),
      '#attributes' => array('class' => array('draggable')),
    );
    $form['settings']['popup_settings']['yashare_popup_services'][$codename . '_popup_weight'] = array(
      '#tree' => FALSE,
      '#type' => 'weight',
      '#delta' => 30,
      '#default_value' => $weight++,
      '#attributes' => array('class' => array('yashare-popup-services-weight')),
    );
  }
  $form['settings']['popup_settings']['yashare_popup_services'] += array(
    '#type' => 'tableselect',
    '#title' => t('Popup services'),
    '#header' => $header,
    '#options' => $options,
    '#default_value' => $enabled_services,
    '#pre_render' => array('yashare_popup_services_pre_render'),
  );

  $form['#validate'] = array('yashare_admin_settings_validate');
  return system_settings_form($form);
}

/**
 * Pre-render callback for the block services tableselect.
 */
function yashare_block_services_pre_render($element) {
  return yashare_services_tableselect_pre_render($element, 'block');
}

/**
 * Pre-render callback for the popup services tableselect.
 */
function yashare_popup_services_pre_render($element) {
  return yashare_services_tableselect_pre_render($element, 'popup');
}

/**
 * Pre-render callback helper.
 */
function yashare_services_tableselect_pre_render($element, $type) {
  // Add weight column.
  $element['#header']['weight'] = t('Weight');
  foreach (array_keys($element['#options']) as $codename) {
    $key = $codename . '_' . $type . '_weight';
    $element['#options'][$codename]['weight'] = array(
      'data' => drupal_render($element[$key]),
    );
    unset($element[$key]);
  }

  // Assign id to the table.
  $table_id = 'yashare-' . $type . '-services';
  $element['#attributes'] = array('id' => $table_id);
  drupal_add_tabledrag($table_id, 'order', 'sibling', 'yashare-' . $type . '-services-weight');
  return $element;
}

function yashare_admin_settings_validate($form, &$form_state) {
  $values = &$form_state['values'];
  $services = yashare_services_list();
  // Remove weights so they are not saved as variables.
  foreach (array_keys($services) as $codename) {
    $block_services[$codename] = $values[$codename . '_block_weight'];
    $popup_services[$codename] = $values[$codename . '_popup_weight'];
    unset($values[$codename . '_block_weight']);
    unset($values[$codename . '_popup_weight']);
  }
  asort($block_services);
  asort($popup_services);

  $block_services_values = $values['yashare_block_services'];
  $popup_services_values = $values['yashare_popup_services'];
  unset($values['yashare_block_services']);
  unset($values['yashare_popup_services']);

  foreach (array_keys($block_services) as $codename) {
    $values['yashare_block_services'][$codename] = $block_services_values[$codename];
  }
  foreach (array_keys($popup_services) as $codename) {
    $values['yashare_popup_services'][$codename] = $popup_services_values[$codename];
  }
}

/**
 * Render Yandex.Share block for admin settings form.
 */
function yashare_render($id = NULL, $link = NULL, $title = NULL, $description = NULL, $type = NULL) {
  $element = array(
    '#type' => 'yashare_widget',
    '#id' => $id,
    '#html_tag' => 'span',
    '#link' => $link,
    '#title' => $title,
    '#description' => $description,
    '#yashare_type' => $type,
  );
  return drupal_render($element);
}
